@@ -2,6 +2,5 @@ from ._lce import LCEClassifier
 from ._lce import LCERegressor
 from ._version import __version__
 
-__all__ = ['LCEClassifier', 
-           'LCERegressor',
-           '__version__']
+
+__all__ = ["LCEClassifier", "LCERegressor", "__version__"]
